@@ -31,7 +31,11 @@ static int altlog_write(const char *str)
     lock.l_pid = getpid();
     lock.l_type = F_WRLCK;
     while (fcntl(altlog_fd, F_SETLKW, &lock) < 0 && errno == EINTR);
-    if (lseek(altlog_fd, (off_t) 0, SEEK_END) < (off_t) 0) {
+    if (lseek(altlog_fd, (off_t) 0, SEEK_END) < (off_t) 0
+# ifdef ESPIPE
+	&& errno != ESPIPE
+# endif
+	) {
         return -1;
     }
     (void) safe_write(altlog_fd, str, (size_t) left);
