@@ -12,15 +12,18 @@ cap_value_t cap_keep_startup[] = {
     CAP_CHOWN,
     CAP_NET_BIND_SERVICE,
     CAP_SYS_CHROOT,
+    CAP_SYS_NICE,
     CAP_NET_ADMIN,
     CAP_DAC_READ_SEARCH
 };
 
 cap_value_t cap_keep_login[] = {
-# ifndef HAVE_SYS_FSUID_H
+# ifndef WITH_PRIVSEP
+#  ifndef HAVE_SYS_FSUID_H
     CAP_SETUID,
-# endif
+#  endif
     CAP_NET_BIND_SERVICE,
+# endif
     CAP_NET_ADMIN
 };
 
