@@ -60,7 +60,11 @@ struct reply {
 };
 
 static const char *GETOPT_OPTIONS =
-    "0146Aa:bc:"
+    "0146"
+#ifdef WITH_RFC2640
+    "8:9:"
+#endif
+    "Aa:bc:"
 #ifndef NO_STANDALONE
     "BC:"
 #endif
@@ -93,7 +97,7 @@ static const char *GETOPT_OPTIONS =
     "t:T:"
 #endif
     "u:U:V:wWxX"
-#ifdef WITH_OSX_RENDEZVOUS
+#ifdef WITH_OSX_BONJOUR
     "v:"
 #endif
 #ifdef PER_USER_LIMITS
@@ -110,6 +114,10 @@ static struct option long_options[] = {
     { "logpid", 0, NULL, '1' },
     { "ipv4only", 0, NULL, '4' },
     { "ipv6only", 0, NULL, '6' },    
+#ifdef WITH_RFC2640
+    { "fscharset", 1, NULL, '8' },
+    { "clientcharset", 1, NULL, '9' },
+#endif
     { "chrooteveryone", 0, NULL, 'A' },
     { "trustedgid", 1, NULL, 'a' },
     { "brokenclientscompatibility", 0, NULL, 'b' },
@@ -168,8 +176,8 @@ static struct option long_options[] = {
     { "umask", 1, NULL, 'U' },
     { "minuid", 1, NULL, 'u' },
     { "trustedip", 1, NULL, 'V' },
-#ifdef WITH_OSX_RENDEZVOUS
-    { "rendezvous", 1, NULL, 'v' },
+#ifdef WITH_OSX_BONJOUR
+    { "bonjour", 1, NULL, 'v' },
 #endif
     { "allowuserfxp", 0, NULL, 'w' },
     { "allowanonymousfxp", 0, NULL, 'W' },
